@@ -281,8 +281,16 @@ class RequestQueuer(object):
                     self.last_req[host] = time.time()
                     self.active_reqs[host] = self.active_reqs.get(host, 0) + 1
             if not dispatched_requests:
+                LOGGER.critical("Done with Check active. (1) Active: %s, Max Simul: %s, Pending: %s" % (
+                    self.getActive(),
+                    self.max_simul_reqs,
+                    self.getPending()))
                 return
-                
+        LOGGER.critical("Done with Check active. (2) Active: %s, Max Simul: %s, Pending: %s" % (
+            self.getActive(),
+            self.max_simul_reqs,
+            self.getPending()))
+                            
     def _requestComplete(self, response, deferred, host):
         self.active_reqs[host] -= 1
         self._checkActive()
